@@ -4,13 +4,13 @@ from datetime import datetime, timedelta
 
 from sf_virtual_data import virtual_sfv
 from . import solar_focus_tables_lib as sofoc
-from common.models import VTCommandLineArgsBase
-from common.api import virtual_tables_pb2
-from common.api import solar_field_pb2
-from common.api import solar_field_common_pb2
-from common.api import virtual_sfv_pb2
-from common.api import virtual_trends_pb2
-from common.api import common_models_pb2
+from sf_virtual_data.common.models import VTCommandLineArgsBase
+from sf_virtual_data.common.api import virtual_tables_pb2
+from sf_virtual_data.common.api import solar_field_pb2
+from sf_virtual_data.common.api import solar_field_common_pb2
+from sf_virtual_data.common.api import virtual_sfv_pb2
+from sf_virtual_data.common.api import virtual_trends_pb2
+from sf_virtual_data.common.api import common_models_pb2
 from virtual_sfv import solar_focus_sfv_lib as virtual_sfv_lib
 from virtual_trend import solar_focus_trends_lib as virtual_trends_lib
 import google.protobuf.json_format as json_format
